@@ -1,7 +1,7 @@
 #!/usr/bin/env python
-import shutil
 import itertools
 import random
+import shutil
 import sys
 import traceback
 from pathlib import Path
@@ -12,9 +12,10 @@ import plotly as plotly
 import plotly.express as px
 import plotly.graph_objects as go
 import streamlit as st
+from negmas.helpers import unique_name
 from pandas.api.types import is_numeric_dtype
 from plotly.validators.scatter.marker import SymbolValidator
-from streamlit import cli as stcli
+from streamlit.web import cli as stcli
 
 import scml_vis.compiler as compiler
 from scml_vis.compiler import VISDATA_FOLDER
@@ -32,7 +33,9 @@ __all__ = ["main"]
 
 
 MARKERS = SymbolValidator().values[2::3]
-MARKERS = [_ for _ in MARKERS if not any(_.startswith(x) for x in ("star", "circle", "square"))]
+MARKERS = [
+    _ for _ in MARKERS if not any(_.startswith(x) for x in ("star", "circle", "square"))
+]
 random.shuffle(MARKERS)
 MARKERS = ["circle", "square"] + MARKERS
 
@@ -70,7 +73,9 @@ def main(folder: Path):
                         continue
                     options[child] = f"{'t' if type_ else 'w'}:{child.name}"
 
-        folder = st.sidebar.selectbox("Select a run", list(options.keys()), format_func=lambda x: options[x])
+        folder = st.sidebar.selectbox(
+            "Select a run", list(options.keys()), format_func=lambda x: options[x]
+        )
     if not folder or (isinstance(folder, str) and folder == "none"):
         st.text(
             "Cannot find any folders with logs.\nTry looking in default paths by checking 'Add Default paths' \nin the side bar or start the app with a folder containing log data using -f"
@@ -82,7 +87,9 @@ def main(folder: Path):
     if folder.exists():
         re_compile = st.sidebar.button("Recompile visualization data?")
         if re_compile:
-            st.error("Do you really, really, want to remove all visuallization data and recopmile?")
+            st.error(
+                "Do you really, really, want to remove all visuallization data and recopmile?"
+            )
             if st.button("Yes I'm OK with that"):
                 shutil.rmtree(folder)
 
@@ -93,10 +100,14 @@ def main(folder: Path):
                 try:
                     compiler.main(folder.parent, max_worlds=None)
                 except Exception as e:
-                    st.write(f"*Failed to compile visualization data for {folder}*\n### Exception:\n{str(e)}")
+                    st.write(
+                        f"*Failed to compile visualization data for {folder}*\n### Exception:\n{str(e)}"
+                    )
                     st.write(f"\n### Traceback:\n```\n{traceback.format_exc()}```")
             else:
-                st.text("Either press 'Compile visualization data' to view logs of this folder or choose another one.")
+                st.text(
+                    "Either press 'Compile visualization data' to view logs of this folder or choose another one."
+                )
                 return
         except:
             st.write(f"Folder {folder} contains no logs to use")
@@ -147,27 +158,42 @@ def main(folder: Path):
         worlds = load_data(folder, "worlds")
     if "config" not in worlds.columns:
         worlds["config"] = worlds.loc[:, "name"].str.split("_").str[0]
-    worlds = worlds.loc[worlds.tournament.isin(selected_tournaments) & worlds.config.isin(selected_configs), :]
+    worlds = worlds.loc[
+        worlds.tournament.isin(selected_tournaments)
+        & worlds.config.isin(selected_configs),
+        :,
+    ]
     world_expander = st.sidebar.expander("World Selection")
     with world_expander:
-        selected_worlds, _, _ = add_selector(st, "", worlds.name, key="worlds", none=False, default="all")
+        selected_worlds, _, _ = add_selector(
+            st, "", worlds.name, key="worlds", none=False, default="all"
+        )
     worlds = worlds.loc[(worlds.name.isin(selected_worlds)), :]
 
     agents = load_data(folder, "agents")
     type_expander = st.sidebar.expander("Type Selection")
     with type_expander:
-        selected_types, _, _ = add_selector(st, "", agents.type.unique(), key="types", none=False, default="all")
+        selected_types, _, _ = add_selector(
+            st, "", agents.type.unique(), key="types", none=False, default="all"
+        )
     agents = agents.loc[(agents.type.isin(selected_types)), :]
 
     agent_expander = st.sidebar.expander("Agent Selection")
     with agent_expander:
-        selected_agents, _, _ = add_selector(st, "", agents.name.unique(), key="agents", none=False, default="all")
+        selected_agents, _, _ = add_selector(
+            st, "", agents.name.unique(), key="agents", none=False, default="all"
+        )
 
     products = load_data(folder, "product_stats")
     product_expander = st.sidebar.expander("Product Selection")
     with product_expander:
         selected_products, _, _ = add_selector(
-            st, "", products["product"].unique(), key="products", none=False, default="all"
+            st,
+            "",
+            products["product"].unique(),
+            key="products",
+            none=False,
+            default="all",
         )
 
     agents = agents.loc[(agents.type.isin(selected_types)), :]
@@ -199,7 +225,9 @@ def main(folder: Path):
     #         st.text("Please choose what type of figures are you interested in")
     #         return
     products_summary = (
-        products.loc[:, [_ for _ in products.columns if _ not in ("step", "relative_time")]]
+        products.loc[
+            :, [_ for _ in products.columns if _ not in ("step", "relative_time")]
+        ]
         .groupby(["tournament", "world", "product"])
         .agg(["min", "max", "mean", "std"])
     )
@@ -236,7 +264,9 @@ def main(folder: Path):
     ]:
         if section_name != "Time Series":
             expander = st.sidebar.expander(section_name, section_name == "Networks")
-            do_expand = expander.checkbox(f"Show {section_name}", section_name == "Networks")
+            do_expand = expander.checkbox(
+                f"Show {section_name}", section_name == "Networks"
+            )
         else:
             expander = st.sidebar
             do_expand = st.sidebar.checkbox(section_name, True)
@@ -302,10 +332,17 @@ def show_a_world(
     nodes = {n["name"]: n for n in nodes}
     seller_dict = dict(zip(fields, itertools.repeat(float("nan"))))
     buyer_dict = dict(zip(fields, itertools.repeat(float("nan"))))
-    nodes["SELLER"] = {**seller_dict, **dict(pos=(0, dy * (level_max[0] // 2)), name="Seller", type="System")}
+    nodes["SELLER"] = {
+        **seller_dict,
+        **dict(pos=(0, dy * (level_max[0] // 2)), name="Seller", type="System"),
+    }
     nodes["BUYER"] = {
         **buyer_dict,
-        **dict(pos=((nlevels + 1) * dx, dy * (level_max[-1] // 2)), name="Buyer", type="System"),
+        **dict(
+            pos=((nlevels + 1) * dx, dy * (level_max[-1] // 2)),
+            name="Buyer",
+            type="System",
+        ),
     }
     edges, weights = [], []
     weight_field_name = "quantity" if weight_field == "count" else weight_field
@@ -315,7 +352,12 @@ def show_a_world(
         else ["step", "relative_time"]
     )
     x = x.loc[x.world == world, [weight_field_name, "seller", "buyer"] + time_cols]
-    x = filter_by_time(x, [condition_field + "_" if condition_field != "step" else ""], selected_steps, selected_times)
+    x = filter_by_time(
+        x,
+        [condition_field + "_" if condition_field != "step" else ""],
+        selected_steps,
+        selected_times,
+    )
     x.drop(time_cols, axis=1, inplace=True)
     if weight_field == "unit_price":
         x = x.groupby(["seller", "buyer"]).mean().reset_index()
@@ -329,7 +371,12 @@ def show_a_world(
         edges.append((d["seller"], d["buyer"], d[weight_field]))
     parent.plotly_chart(
         plot_network(
-            fields, nodes, edges=edges, node_weights=node_weight, edge_colors=edge_colors, edge_weights=edge_weights
+            fields,
+            nodes,
+            edges=edges,
+            node_weights=node_weight,
+            edge_colors=edge_colors,
+            edge_weights=edge_weights,
         )
     )
     if gallery:
@@ -339,10 +386,17 @@ def show_a_world(
     mydata = data[src]
     myselected = mydata.loc[(mydata.world == world), :]
     myselected = filter_by_time(
-        myselected, [condition_field + "_" if condition_field != "step" else ""], selected_steps, selected_times
+        myselected,
+        [condition_field + "_" if condition_field != "step" else ""],
+        selected_steps,
+        selected_times,
+    )
+    seller = col1.selectbox(
+        "Seller", [""] + sorted(x["seller"].unique()), key=f"seller-{world}"
+    )
+    buyer = col2.selectbox(
+        "Buyer", [""] + sorted(x["buyer"].unique()), key=unique_name(f"seller-{world}")
     )
-    seller = col1.selectbox("Seller", [""] + sorted(x["seller"].unique()), key=f"seller-{world}")
-    buyer = col2.selectbox("Buyer", [""] + sorted(x["buyer"].unique()), key=f"seller-{world}")
     if seller:
         myselected = myselected.loc[(myselected.seller == seller), :]
     if buyer:
@@ -378,26 +432,44 @@ def show_a_world(
             + (["seller"] if not seller else [])
         )
     elif src == "n":
-        displayed_cols = ["id", "delivery_step", "quantity", "unit_price", "timedout", "broken", "step", "rounds"]
+        displayed_cols = [
+            "id",
+            "delivery_step",
+            "quantity",
+            "unit_price",
+            "timedout",
+            "broken",
+            "step",
+            "rounds",
+        ]
     else:
         return
     parent.dataframe(
         myselected.loc[:, displayed_cols].sort_values(
-            ["signed_step", "delivery_step"] if src == "c" else ["step", "delivery_step"]
+            ["signed_step", "delivery_step"]
+            if src == "c"
+            else ["step", "delivery_step"]
         )
     )
     contract = None
 
     options = filter_by_time(
-        options, [condition_field + "_" if condition_field != "step" else ""], selected_steps, selected_times
+        options,
+        [condition_field + "_" if condition_field != "step" else ""],
+        selected_steps,
+        selected_times,
     )
     if parent.checkbox("Ignore Exogenous", key=f"ignore-exogenous-{world}", value=True):
-        options = options.loc[(options["buyer"] != "BUYER") & (options["seller"] != "SELLER"), :]
+        options = options.loc[
+            (options["buyer"] != "BUYER") & (options["seller"] != "SELLER"), :
+        ]
     if src == "n":
         options = options.loc[:, "id"].values
         if len(options) < 1:
             return
-        neg = parent.selectbox(label="Negotiation", options=options, key=f"negotiationselect-{world}")
+        neg = parent.selectbox(
+            label="Negotiation", options=options, key=f"negotiationselect-{world}"
+        )
     elif src == "c":
         options = options.loc[:, "id"].values
         if len(options) < 1:
@@ -405,7 +477,9 @@ def show_a_world(
         elif len(options) == 1:
             contract = options[0]
         else:
-            contract = parent.selectbox(label="Contract", options=options, key=f"contractselect-{world}")
+            contract = parent.selectbox(
+                label="Contract", options=options, key=f"contractselect-{world}"
+            )
         neg = myselected.loc[myselected["id"] == contract, "negotiation"]
         if len(neg) > 0:
             neg = neg.values[0]
@@ -445,7 +519,9 @@ def show_a_world(
         is_3d = c2.checkbox("3D Graph", key=f"threed-{world}")
     else:
         is_3d = False
-    use_ranges = c1.checkbox("Use issue ranges to set axes", True, key=f"useissueranges-{world}")
+    use_ranges = c1.checkbox(
+        "Use issue ranges to set axes", True, key=f"useissueranges-{world}"
+    )
     qrange = (neg_info["min_quantity"] - 1, neg_info["max_quantity"] + 1)
     urange = (neg_info["min_unit_price"] - 1, neg_info["max_unit_price"] + 1)
     if is_3d:
@@ -532,7 +608,13 @@ def show_a_world(
                 )
             )
         fig.update_layout(xaxis_title="Round", yaxis_title=y)
-        fig.update_layout(yaxis_range=urange if y == "unit_price" else qrange if y == "quantity" else trange)
+        fig.update_layout(
+            yaxis_range=urange
+            if y == "unit_price"
+            else qrange
+            if y == "quantity"
+            else trange
+        )
         return fig
 
     col1.plotly_chart(fig_1d("quantity"))
@@ -565,7 +647,9 @@ def display_networks(
         st.write("No worlds selected. Cannot show any networks")
         return
     if len(selected_worlds) > max_worlds:
-        st.write(f"More than {max_worlds} world selected ({len(selected_worlds)}). Will show the first {max_worlds}")
+        st.write(
+            f"More than {max_worlds} world selected ({len(selected_worlds)}). Will show the first {max_worlds}"
+        )
         cols = st.columns([1, 5, 1, 3])
         # prev = cols[0].button("<")
         # next = cols[2].button(">")
@@ -591,26 +675,38 @@ def display_networks(
         return
     gallery = parent.checkbox("Gallery Mode", len(selected_worlds) > 1)
     node_weight_options = sorted(
-        [_ for _ in data["a"].columns if is_numeric_dtype(data["a"][_]) and _ not in ("id", "is_default")]
+        [
+            _
+            for _ in data["a"].columns
+            if is_numeric_dtype(data["a"][_]) and _ not in ("id", "is_default")
+        ]
     )
     default_node_weight = node_weight_options.index("final_score")
     if default_node_weight is None:
         default_node_weight = 0
     with st.expander("Networks Settings"):
         cols = st.columns(5 + int(gallery))
-        weight_field = cols[2].selectbox("Edge Weight", ["total_price", "unit_price", "quantity", "count"])
-        node_weight = cols[3].selectbox("Node Weight", ["none"] + node_weight_options, default_node_weight + 1)
+        weight_field = cols[2].selectbox(
+            "Edge Weight", ["total_price", "unit_price", "quantity", "count"]
+        )
+        node_weight = cols[3].selectbox(
+            "Node Weight", ["none"] + node_weight_options, default_node_weight + 1
+        )
         per_step = cols[0].checkbox("Show one step only")
         edge_weights = cols[0].checkbox("Variable Edge Width", True)
         edge_colors = cols[0].checkbox("Variable Edge Colors", True)
         if per_step:
-            selected_step = cols[1].number_input("Step", selected_steps[0], selected_steps[1], selected_steps[0])
+            selected_step = cols[1].number_input(
+                "Step", selected_steps[0], selected_steps[1], selected_steps[0]
+            )
             selected_steps = [selected_step] * 2
         x["total_price"] = x.quantity * x.unit_price
         options = [_[: -len("_step")] for _ in x.columns if _.endswith("_step")]
         if src != "c":
             options.append("step")
-        condition_field = cols[4].selectbox("Condition", options, 0 if src != "n" else options.index("step"))
+        condition_field = cols[4].selectbox(
+            "Condition", options, 0 if src != "n" else options.index("step")
+        )
     if gallery:
         n_cols = cols[5].number_input("Columns", 1, 5, 2)
         cols = st.columns(n_cols)
@@ -708,35 +804,51 @@ def display_tables(
         ("Negotiations", "n", True),
         ("Offers", "o", True),
     ):
-
         if data[k] is None or not len(data[k]):
             continue
         if not parent.checkbox(label=lbl, key=f"tbl-{lbl}-c1"):
             continue
         if has_step:
             df = filter_by_time(
-                data[k], ["signed_", "concluded_"] if k == "c" else [""], selected_steps, selected_times
+                data[k],
+                ["signed_", "concluded_"] if k == "c" else [""],
+                selected_steps,
+                selected_times,
             )
         else:
             df = data[k]
         if lbl == "Agents":
-            if st.checkbox("Ignore Default Agents", True, key=f"tbl-{lbl}-ignore-default"):
+            if st.checkbox(
+                "Ignore Default Agents", True, key=f"tbl-{lbl}-ignore-default"
+            ):
                 df = df.loc[~df["is_default"], :]
         elif lbl == "Contracts":
-            if st.checkbox("Ignore Exogenous Contracts", True, key=f"tbl-{lbl}-ignore-exogenous"):
+            if st.checkbox(
+                "Ignore Exogenous Contracts", True, key=f"tbl-{lbl}-ignore-exogenous"
+            ):
                 df = df.loc[df["n_neg_steps"] < 1, :]
         show_table(df)
         st.text(f"{len(df)} records found")
         cols = st.columns(6)
-        type_ = cols[0].selectbox("Chart", ["Scatter", "Line", "Bar", "Box"], 0, key=f"select-{lbl}-chart")
+        type_ = cols[0].selectbox(
+            "Chart", ["Scatter", "Line", "Bar", "Box"], 0, key=f"select-{lbl}-chart"
+        )
         x = cols[1].selectbox("x", ["none"] + list(df.columns), key=f"select-{lbl}-x")
         y = m = c = s = "none"
         if x != "none":
-            y = cols[2].selectbox("y", ["none"] + list(df.columns), key=f"select-{lbl}-y")
+            y = cols[2].selectbox(
+                "y", ["none"] + list(df.columns), key=f"select-{lbl}-y"
+            )
             if y != "none":
-                m = cols[3].selectbox("Mark", ["none"] + list(df.columns), key=f"select-{lbl}-mark")
-                c = cols[4].selectbox("Color", ["none"] + list(df.columns), key=f"select-{lbl}-color")
-                s = cols[5].selectbox("Size", ["none"] + list(df.columns), key=f"select-{lbl}-size")
+                m = cols[3].selectbox(
+                    "Mark", ["none"] + list(df.columns), key=f"select-{lbl}-mark"
+                )
+                c = cols[4].selectbox(
+                    "Color", ["none"] + list(df.columns), key=f"select-{lbl}-color"
+                )
+                s = cols[5].selectbox(
+                    "Size", ["none"] + list(df.columns), key=f"select-{lbl}-size"
+                )
                 kwargs = dict(x=x, y=y)
                 if m != "none":
                     kwargs["shape"] = m
@@ -763,32 +875,77 @@ def display_time_series(
 ):
     settings = st.expander("Time Series Settings")
     ncols = settings.number_input("N. Columns", 1, 6, 2)
-    xvar = settings.selectbox("x-variable", ["step", "relative_time"], 1 - int(len(selected_worlds) == 1))
+    xvar = settings.selectbox(
+        "x-variable", ["step", "relative_time"], 1 - int(len(selected_worlds) == 1)
+    )
     dynamic = settings.checkbox("Dynamic Figures", value=True)
     sectioned = settings.checkbox("Figure Sections", True)
     ci_level = settings.selectbox(options=[80, 90, 95], label="CI Level", index=2)
-    world_stats, selected_world_stats, combine_world_stats, overlay_world_stats = add_stats_selector(
+    (
+        world_stats,
+        selected_world_stats,
+        combine_world_stats,
+        overlay_world_stats,
+    ) = add_stats_selector(
         folder,
         "world_stats",
-        [[("world", selected_worlds), ("step", selected_steps), ("relative_time", selected_times)]],
+        [
+            [
+                ("world", selected_worlds),
+                ("step", selected_steps),
+                ("relative_time", selected_times),
+            ]
+        ],
         xvar=xvar,
         label="World Statistics",
         choices=lambda x: [
-            _ for _ in x.columns if _ not in ("name", "world", "name", "tournament", "type", "step", "relative_time")
+            _
+            for _ in x.columns
+            if _
+            not in (
+                "name",
+                "world",
+                "name",
+                "tournament",
+                "type",
+                "step",
+                "relative_time",
+            )
         ],
         default_selector="one",
     )
 
-    product_stats, selected_product_stats, combine_product_stats, overlay_product_stats = add_stats_selector(
+    (
+        product_stats,
+        selected_product_stats,
+        combine_product_stats,
+        overlay_product_stats,
+    ) = add_stats_selector(
         folder,
         "product_stats",
-        [[("product", selected_products), ("step", selected_steps), ("relative_time", selected_times)]],
+        [
+            [
+                ("product", selected_products),
+                ("step", selected_steps),
+                ("relative_time", selected_times),
+            ]
+        ],
         xvar=xvar,
         label="Product Statistics",
         choices=lambda x: [
             _
             for _ in x.columns
-            if _ not in ("name", "world", "name", "tournament", "type", "step", "product", "relative_time")
+            if _
+            not in (
+                "name",
+                "world",
+                "name",
+                "tournament",
+                "type",
+                "step",
+                "product",
+                "relative_time",
+            )
         ],
         default_selector="some",
         default_choice=["trading_price"],
@@ -806,7 +963,12 @@ def display_time_series(
         "spot_market_quantity",
     ]
 
-    type_stats, selected_type_stats, combine_type_stats, overlay_type_stats = add_stats_selector(
+    (
+        type_stats,
+        selected_type_stats,
+        combine_type_stats,
+        overlay_type_stats,
+    ) = add_stats_selector(
         folder,
         "agent_stats",
         [
@@ -820,7 +982,18 @@ def display_time_series(
         xvar=xvar,
         label="Type Statistics",
         choices=lambda x: [
-            _ for _ in x.columns if _ not in ("name", "world", "name", "tournament", "type", "step", "relative_time")
+            _
+            for _ in x.columns
+            if _
+            not in (
+                "name",
+                "world",
+                "name",
+                "tournament",
+                "type",
+                "step",
+                "relative_time",
+            )
         ],
         key="type",
         default_selector="some" if len(selected_worlds) != 1 else "none",
@@ -829,7 +1002,12 @@ def display_time_series(
         overlay=False,
     )
 
-    agent_stats, selected_agent_stats, combine_agent_stats, overlay_agent_stats = add_stats_selector(
+    (
+        agent_stats,
+        selected_agent_stats,
+        combine_agent_stats,
+        overlay_agent_stats,
+    ) = add_stats_selector(
         folder,
         "agent_stats",
         [
@@ -843,7 +1021,18 @@ def display_time_series(
         xvar=xvar,
         label="Agent Statistics",
         choices=lambda x: [
-            _ for _ in x.columns if _ not in ("name", "world", "name", "tournament", "type", "step", "relative_time")
+            _
+            for _ in x.columns
+            if _
+            not in (
+                "name",
+                "world",
+                "name",
+                "tournament",
+                "type",
+                "step",
+                "relative_time",
+            )
         ],
         default_selector="some" if len(selected_worlds) == 1 else "none",
         default_choice=default_agent_stats if len(selected_worlds) == 1 else None,
@@ -877,7 +1066,9 @@ def display_time_series(
         label="Contract Statistics (World)",
         default_selector="none",
         choices=lambda x: [
-            _ for _ in x.columns if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
+            _
+            for _ in x.columns
+            if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
         ],
         key="world",
     )
@@ -908,7 +1099,9 @@ def display_time_series(
         label="Contract Statistics (Types)",
         default_selector="none",
         choices=lambda x: [
-            _ for _ in x.columns if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
+            _
+            for _ in x.columns
+            if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
         ],
         key="type",
     )
@@ -938,13 +1131,19 @@ def display_time_series(
         label="Contract Statistics (Agents)",
         default_selector="none",
         choices=lambda x: [
-            _ for _ in x.columns if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
+            _
+            for _ in x.columns
+            if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
         ],
         key="name",
     )
 
     def aggregate_contract_stats(stats, ignored_cols):
-        cols = [_ for _ in stats.columns if not any(_.endswith(x) for x in ["price", "quantity", "count"])]
+        cols = [
+            _
+            for _ in stats.columns
+            if not any(_.endswith(x) for x in ["price", "quantity", "count"])
+        ]
         ignored_cols = [_ for _ in cols if _.startswith(ignored_cols)]
         cols = [_ for _ in cols if not _ in ignored_cols]
         allcols = [_ for _ in stats.columns if not _ in ignored_cols]
@@ -983,7 +1182,9 @@ def display_time_series(
         label="Contract Statistics (Buyer Types)",
         default_selector="none",
         choices=lambda x: [
-            _ for _ in x.columns if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
+            _
+            for _ in x.columns
+            if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
         ],
         key="buyer_type",
     )
@@ -1008,7 +1209,9 @@ def display_time_series(
         label="Contract Statistics (Seller Types)",
         default_selector="none",
         choices=lambda x: [
-            _ for _ in x.columns if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
+            _
+            for _ in x.columns
+            if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
         ],
         key="seller_type",
     )
@@ -1033,7 +1236,9 @@ def display_time_series(
         label="Contract Statistics (Buyer)",
         default_selector="none",
         choices=lambda x: [
-            _ for _ in x.columns if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
+            _
+            for _ in x.columns
+            if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
         ],
         key="buyer",
     )
@@ -1059,20 +1264,34 @@ def display_time_series(
         label="Contract Statistics (Seller)",
         default_selector="none",
         choices=lambda x: [
-            _ for _ in x.columns if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
+            _
+            for _ in x.columns
+            if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
         ],
         key="seller",
     )
 
     contract_stats_buyer = aggregate_contract_stats(contract_stats_buyer, "seller")
     contract_stats_seller = aggregate_contract_stats(contract_stats_seller, "buyer")
-    contract_stats_buyer_type = aggregate_contract_stats(contract_stats_buyer, "seller_type")
-    contract_stats_seller_type = aggregate_contract_stats(contract_stats_seller, "buyer_type")
+    contract_stats_buyer_type = aggregate_contract_stats(
+        contract_stats_buyer, "seller_type"
+    )
+    contract_stats_seller_type = aggregate_contract_stats(
+        contract_stats_seller, "buyer_type"
+    )
 
-    contract_stats_agent["agent"] = contract_stats_agent["seller"] + "->" + contract_stats_agent["buyer"]
-    contract_stats_agent["agent_type"] = contract_stats_agent["seller_type"] + "->" + contract_stats_agent["buyer_type"]
-    contract_stats_type["agent"] = contract_stats_type["seller"] + "->" + contract_stats_type["buyer"]
-    contract_stats_type["agent_type"] = contract_stats_type["seller_type"] + "->" + contract_stats_type["buyer_type"]
+    contract_stats_agent["agent"] = (
+        contract_stats_agent["seller"] + "->" + contract_stats_agent["buyer"]
+    )
+    contract_stats_agent["agent_type"] = (
+        contract_stats_agent["seller_type"] + "->" + contract_stats_agent["buyer_type"]
+    )
+    contract_stats_type["agent"] = (
+        contract_stats_type["seller"] + "->" + contract_stats_type["buyer"]
+    )
+    contract_stats_type["agent_type"] = (
+        contract_stats_type["seller_type"] + "->" + contract_stats_type["buyer_type"]
+    )
 
     (
         contract_stats_product,
@@ -1100,7 +1319,9 @@ def display_time_series(
         label="Contract Statistics (Product)",
         default_selector="none",
         choices=lambda x: [
-            _ for _ in x.columns if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
+            _
+            for _ in x.columns
+            if _.endswith("quantity") or _.endswith("count") or _.endswith("price")
         ],
         key="product",
     )
@@ -1305,22 +1526,26 @@ def display_others(
     # settings = parent.expander("Settings")
     # ncols = settings.number_input("N. Columns", min_value=1, max_value=6)
     if parent.checkbox("Score Distribution", False):
-        score_distribution(selected_worlds, selected_agents, selected_types, data, parent=parent)
+        score_distribution(
+            selected_worlds, selected_agents, selected_types, data, parent=parent
+        )
     if parent.checkbox("Final Score Factors", False):
-        score_factors(selected_worlds, selected_agents, selected_types, data, parent=parent)
+        score_factors(
+            selected_worlds, selected_agents, selected_types, data, parent=parent
+        )
 
 
 if __name__ == "__main__":
     import sys
 
-    from streamlit import cli as stcli
+    from streamlit.web import cli as stcli
 
     folder = None
     if len(sys.argv) > 1:
         folder = Path(sys.argv[1])
 
-    if st._is_running_with_streamlit:
-        main(folder)
-    else:
-        sys.argv = ["streamlit", "run"] + sys.argv
-        sys.exit(stcli.main())
+    # if st._is_running_with_streamlit:
+    main(folder)
+    # else:
+    # sys.argv = ["streamlit", "run"] + sys.argv
+    # sys.exit(stcli.main())
